combine_omics Combine two or more omics matrices into one multi-omics matrix with 'tagged' ids.
combine_omics.Rdcombine_omics Combine two or more omics matrices into one multi-omics matrix with 'tagged' ids.
Examples
library(leapR)
library(BiocFileCache)
path <- tools::R_user_dir("leapR", which = "cache")
bfc <- BiocFileCache(path, ask = FALSE)
url <- "https://api.figshare.com/v2/file/download/56536217"
pc <- bfcadd(bfc, "pdat", fpath = url)
#>
#> Error while performing HEAD request.
#> Proceeding without cache information.
load(pc)
url <- "https://api.figshare.com/v2/file/download/56536214"
tc <- bfcadd(bfc, "tdat", fpath = url)
#>
#> Error while performing HEAD request.
#> Proceeding without cache information.
load(tc)
url <- "https://api.figshare.com/v2/file/download/56536211"
phc <- bfcadd(bfc, "phdat", fpath = url)
#>
#> Error while performing HEAD request.
#> Proceeding without cache information.
load(phc)
# merge the three datasets by rows and add prefix tags for
# different omics types
multi_omics <- combine_omics(list(pset, tset, phset),
list(NA,NA,'hgnc_id'))